@@ -4,18 +4,23 @@
 */
 
 #include "collapsibleeffectview.hpp"
+#include "assets/assetlist/view/assetlistwidget.hpp"
 #include "assets/keyframes/view/keyframeview.hpp"
 #include "assets/view/assetparameterview.hpp"
 #include "assets/view/widgets/colorwheel.h"
-#include "assets/view/widgets/keyframewidget.hpp"
+
+#include "assets/view/widgets/keyframecontainer.hpp"
 #include "core.h"
-#include "filefilter.h"
 #include "effects/effectsrepository.hpp"
 #include "effects/effectstack/model/effectitemmodel.hpp"
+#include "filefilter.h"
 #include "kdenlivesettings.h"
 #include "monitor/monitor.h"
+#include "utils/qstringutils.h"
+#include "widgets/dragvalue.h"
 
 #include "kdenlive_debug.h"
+#include <QComboBox>
 #include <QDialog>
 #include <QFileDialog>
 #include <QFontDatabase>
@@ -32,13 +37,13 @@
 #include <QVBoxLayout>
 #include <QWheelEvent>
 
-#include "utils/KMessageBox_KdenliveCompat.h"
+#include <KColorScheme>
+#include <KColorUtils>
 #include <KDualAction>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KRecentDirs>
 #include <KSqueezedTextLabel>
-#include <QComboBox>
 
 CollapsibleEffectView::CollapsibleEffectView(const QString &effectName, const std::shared_ptr<EffectItemModel> &effectModel, QSize frameSize, QWidget *parent)
     : AbstractCollapsibleWidget(parent)
@@ -55,9 +60,23 @@ CollapsibleEffectView::CollapsibleEffectView(const QString &effectName, const st
     buttonDown->setToolTip(i18n("Move effect down"));
     buttonDown->setWhatsThis(xi18nc(
         "@info:whatsthis", "Moves the effect below the one right below it. Effects are handled sequentially from top to bottom so sequence is important."));
-    buttonDel->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
-    buttonDel->setToolTip(i18n("Delete effect"));
-    buttonDel->setWhatsThis(xi18nc("@info:whatsthis", "Deletes the effect from the effect stack."));
+
+    QPalette pal = palette();
+    KColorScheme scheme(QApplication::palette().currentColorGroup(), KColorScheme::View);
+    m_bgColor = pal.color(QPalette::Active, QPalette::Window);
+    m_bgColorTitle = pal.color(QPalette::Active, QPalette::AlternateBase);
+    // scheme.background(KColorScheme::AlternateBackground).color();
+    // palette().color(QPalette::Active, QPalette::Window);
+    QColor selected_bg = scheme.decoration(KColorScheme::FocusColor).color();
+    m_hoverColor = KColorUtils::mix(m_bgColor, selected_bg, 0.07);
+    m_hoverColorTitle = KColorUtils::mix(m_bgColor, selected_bg, 0.1);
+    QColor hoverColor = scheme.decoration(KColorScheme::HoverColor).color();
+    m_activeColor = KColorUtils::mix(m_bgColor, hoverColor, 0.2);
+    m_activeColorTitle = KColorUtils::mix(m_bgColor, hoverColor, 0.3);
+
+    pal.setColor(QPalette::Inactive, QPalette::Text, pal.shadow().color());
+    pal.setColor(QPalette::Active, QPalette::Text, pal.shadow().color());
+    border_frame->setPalette(pal);
 
     if (effectId == QLatin1String("speed")) {
         // Speed effect is a "pseudo" effect, cannot be moved
@@ -73,8 +92,17 @@ CollapsibleEffectView::CollapsibleEffectView(const QString &effectName, const st
     m_collapse = new KDualAction(i18n("Collapse Effect"), i18n("Expand Effect"), this);
     m_collapse->setActiveIcon(QIcon::fromTheme(QStringLiteral("arrow-right")));
     collapseButton->setDefaultAction(m_collapse);
+    collapseButton->installEventFilter(this);
     m_collapse->setActive(m_model->isCollapsed());
     connect(m_collapse, &KDualAction::activeChanged, this, &CollapsibleEffectView::slotSwitch);
+    infoButton->setIcon(QIcon::fromTheme(QStringLiteral("help-about")));
+    infoButton->setToolTip(i18n("Open effect documentation in browser"));
+    connect(infoButton, &QToolButton::clicked, this, [this]() {
+        const QString id = m_model->getAssetId();
+        AssetListType::AssetType type = EffectsRepository::get()->getType(id);
+        const QUrl link(AssetListWidget::buildLink(id, type));
+        pCore->openDocumentationLink(link);
+    });
 
     if (effectModel->rowCount() == 0) {
         // Effect has no parameter
@@ -84,9 +112,11 @@ CollapsibleEffectView::CollapsibleEffectView(const QString &effectName, const st
         m_collapse->setInactiveIcon(QIcon::fromTheme(QStringLiteral("arrow-down")));
     }
 
+    frame->setAutoFillBackground(true);
     auto *l = static_cast<QHBoxLayout *>(frame->layout());
     title = new KSqueezedTextLabel(this);
     title->setToolTip(effectName);
+    title->setTextElideMode(Qt::ElideRight);
     title->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
     l->insertWidget(1, title);
 
@@ -112,6 +142,18 @@ CollapsibleEffectView::CollapsibleEffectView(const QString &effectName, const st
     m_enabledButton->setInactiveIcon(QIcon::fromTheme(QStringLiteral("visibility")));
     enabledButton->setDefaultAction(m_enabledButton);
     connect(m_model.get(), &AssetParameterModel::enabledChange, this, &CollapsibleEffectView::enableView);
+    if (!effectModel->isAssetEnabled()) {
+        title->setEnabled(false);
+        if (KdenliveSettings::disable_effect_parameters()) {
+            widgetFrame->setEnabled(false);
+        }
+        m_enabledButton->setActive(true);
+    } else {
+        m_enabledButton->setActive(false);
+    }
+    connect(m_enabledButton, &KDualAction::activeChangedByUser, this, &CollapsibleEffectView::slotDisable);
+
+    frame->setMinimumHeight(collapseButton->sizeHint().height());
     connect(m_model.get(), &AssetParameterModel::showEffectZone, this, [=](ObjectId id, QPair<int, int> inOut, bool checked) {
         m_inOutButton->setChecked(checked);
         zoneFrame->setFixedHeight(checked ? frame->height() : 0);
@@ -159,7 +201,14 @@ CollapsibleEffectView::CollapsibleEffectView(const QString &effectName, const st
         if (m_model->getOwnerId().type == KdenliveObjectType::BinClip) {
             m_outPos->setValue(pCore->getMonitor(Kdenlive::ClipMonitor)->position());
         } else {
-            m_inPos->setValue(pCore->getMonitorPosition());
+            int pos = pCore->getMonitorPosition();
+            if (m_model->getOwnerId().type == KdenliveObjectType::TimelineClip) {
+                int min = pCore->getItemPosition(m_model->getOwnerId());
+                int duration = pCore->getItemDuration(m_model->getOwnerId());
+                pos -= min;
+                pos = qBound(0, pos, duration);
+            }
+            m_inPos->setValue(pos);
         }
         updateEffectZone();
     });
@@ -167,7 +216,14 @@ CollapsibleEffectView::CollapsibleEffectView(const QString &effectName, const st
         if (m_model->getOwnerId().type == KdenliveObjectType::BinClip) {
             m_outPos->setValue(pCore->getMonitor(Kdenlive::ClipMonitor)->position());
         } else {
-            m_outPos->setValue(pCore->getMonitorPosition());
+            int pos = pCore->getMonitorPosition();
+            if (m_model->getOwnerId().type == KdenliveObjectType::TimelineClip) {
+                int min = pCore->getItemPosition(m_model->getOwnerId());
+                int duration = pCore->getItemDuration(m_model->getOwnerId());
+                pos -= min;
+                pos = qBound(m_inPos->getValue(), pos, duration);
+            }
+            m_outPos->setValue(pos);
         }
         updateEffectZone();
     });
@@ -184,22 +240,27 @@ CollapsibleEffectView::CollapsibleEffectView(const QString &effectName, const st
     } else {
         zoneFrame->setFixedHeight(0);
     }
-    inOutButton->setVisible(m_model->getOwnerId().type != KdenliveObjectType::TimelineClip);
+    bool displayBuiltInEffect = KdenliveSettings::enableBuiltInEffects() && m_model->isBuiltIn();
+    inOutButton->setVisible(m_model->getOwnerId().type != KdenliveObjectType::TimelineClip && !displayBuiltInEffect);
     connect(m_inPos, &TimecodeDisplay::timeCodeEditingFinished, this, &CollapsibleEffectView::updateEffectZone);
     connect(m_outPos, &TimecodeDisplay::timeCodeEditingFinished, this, &CollapsibleEffectView::updateEffectZone);
     connect(m_inOutButton, &QAction::triggered, this, &CollapsibleEffectView::switchInOut);
 
     title->setText(effectName);
-    frame->setMinimumHeight(collapseButton->sizeHint().height());
+    auto ft = font();
+    ft.setBold(true);
+    title->setFont(ft);
 
     m_view = new AssetParameterView(this);
     const std::shared_ptr<AssetParameterModel> effectParamModel = std::static_pointer_cast<AssetParameterModel>(effectModel);
-    m_view->setModel(effectParamModel, frameSize);
+    m_view->setModel(effectParamModel, frameSize, false);
     connect(m_view, &AssetParameterView::seekToPos, this, &AbstractCollapsibleWidget::seekToPos);
     connect(m_view, &AssetParameterView::activateEffect, this, [this]() {
-        if (!decoframe->property("active").toBool()) {
+        qDebug() << "///// TRYING TO ACTIVATE EFFECT....";
+        if (!m_isActive || !m_model->isAssetEnabled()) {
             // Activate effect if not already active
             Q_EMIT activateEffect(m_model->row());
+            qDebug() << "///// TRYING TO ACTIVATE EFFECT.... DONE";
         }
     });
 
@@ -234,42 +295,59 @@ CollapsibleEffectView::CollapsibleEffectView(const QString &effectName, const st
     presetButton->setToolTip(i18n("Presets"));
     presetButton->setWhatsThis(xi18nc("@info:whatsthis", "Opens a list of advanced options to manage presets for the effect."));
 
-    connect(saveEffectButton, &QAbstractButton::clicked, this, &CollapsibleEffectView::slotSaveEffect);
-    saveEffectButton->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
-    saveEffectButton->setToolTip(i18n("Save effect"));
-
-    if (!effectModel->isEnabled()) {
-        title->setEnabled(false);
-        if (KdenliveSettings::disable_effect_parameters()) {
-            widgetFrame->setEnabled(false);
-        }
-        m_enabledButton->setActive(true);
-    } else {
-        m_enabledButton->setActive(false);
-    }
-
-    connect(m_enabledButton, &KDualAction::activeChangedByUser, this, &CollapsibleEffectView::slotDisable);
+    connect(m_view, &AssetParameterView::saveEffect, this, [this] { slotSaveEffect(); });
     connect(buttonUp, &QAbstractButton::clicked, this, &CollapsibleEffectView::slotEffectUp);
     connect(buttonDown, &QAbstractButton::clicked, this, &CollapsibleEffectView::slotEffectDown);
-    connect(buttonDel, &QAbstractButton::clicked, this, &CollapsibleEffectView::slotDeleteEffect);
+    if (displayBuiltInEffect) {
+        buttonUp->hide();
+        buttonDown->hide();
+        // On builtin effects, delete button becomes a reset button
+        buttonDel->setIcon(QIcon::fromTheme(QStringLiteral("edit-reset")));
+        buttonDel->setToolTip(i18n("Reset Effect"));
+        connect(buttonDel, &QToolButton::clicked, this, &CollapsibleEffectView::slotResetEffect);
+        connect(m_model.get(), &AssetParameterModel::enabledChange, this, [this](bool enable) {
+            presetButton->setEnabled(enable);
+            if (m_model->isAssetEnabled() != enable) {
+                m_model->setAssetEnabled(enable, false);
+                pCore->getMonitor(m_model->monitorId)->slotShowEffectScene(needsMonitorEffectScene());
+            }
+            // Update asset names
+            Q_EMIT effectNamesUpdated();
+        });
+        // frame->hide();
+        decoframe->setProperty("class", "builtin");
+        if (effectId == QLatin1String("qtblend")) {
+            connect(pCore.get(), &Core::enableBuildInTransform, this, &CollapsibleEffectView::enableAndExpand, Qt::QueuedConnection);
+        }
+    } else {
+        buttonDel->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
+        buttonDel->setToolTip(i18n("Delete effect"));
+        buttonDel->setWhatsThis(xi18nc("@info:whatsthis", "Deletes the effect from the effect stack."));
+        connect(buttonDel, &QAbstractButton::clicked, this, &CollapsibleEffectView::slotDeleteEffect);
+    }
 
-    for (QSpinBox *sp : findChildren<QSpinBox *>()) {
+    const QList<QSpinBox *> spins = findChildren<QSpinBox *>();
+    for (QSpinBox *sp : spins) {
         sp->installEventFilter(this);
         sp->setFocusPolicy(Qt::StrongFocus);
     }
-    for (QComboBox *cb : findChildren<QComboBox *>()) {
+    const QList<QComboBox *> combos = findChildren<QComboBox *>();
+    for (QComboBox *cb : combos) {
         cb->installEventFilter(this);
         cb->setFocusPolicy(Qt::StrongFocus);
     }
-    for (QProgressBar *cb : findChildren<QProgressBar *>()) {
+    const QList<QProgressBar *> progs = findChildren<QProgressBar *>();
+    for (QProgressBar *cb : progs) {
         cb->installEventFilter(this);
         cb->setFocusPolicy(Qt::StrongFocus);
     }
-    for (WheelContainer *cb : findChildren<WheelContainer *>()) {
+    const QList<WheelContainer *> wheels = findChildren<WheelContainer *>();
+    for (WheelContainer *cb : wheels) {
         cb->installEventFilter(this);
         cb->setFocusPolicy(Qt::StrongFocus);
     }
-    for (QDoubleSpinBox *cb : findChildren<QDoubleSpinBox *>()) {
+    const QList<QDoubleSpinBox *> dspins = findChildren<QDoubleSpinBox *>();
+    for (QDoubleSpinBox *cb : dspins) {
         cb->installEventFilter(this);
         cb->setFocusPolicy(Qt::StrongFocus);
     }
@@ -294,8 +372,11 @@ void CollapsibleEffectView::updateGroupedInstances()
     if (groupedInstances > 1) {
         auto *l = static_cast<QHBoxLayout *>(frame->layout());
         m_effectInstances = new QLabel(this);
-        int h = (buttonUp->height() - 4) / 3;
-        m_effectInstances->setStyleSheet(QString("margin: 2px; padding: 0px; border-radius: %1px; background: #885500; color: #FFFFFF;").arg(h));
+        QPalette pal = m_effectInstances->palette();
+        KColorScheme scheme(QApplication::palette().currentColorGroup(), KColorScheme::View);
+        const QColor bg = scheme.background(KColorScheme::LinkBackground).color();
+        pal.setColor(QPalette::Active, QPalette::Base, bg);
+        m_effectInstances->setPalette(pal);
         m_effectInstances->setText(QString::number(groupedInstances));
         m_effectInstances->setToolTip(i18n("%1 instances of this effect in the group", groupedInstances));
         m_effectInstances->setMargin(4);
@@ -304,11 +385,6 @@ void CollapsibleEffectView::updateGroupedInstances()
     }
 }
 
-void CollapsibleEffectView::setWidgetHeight(qreal value)
-{
-    widgetFrame->setFixedHeight(int(m_view->contentHeight() * value));
-}
-
 void CollapsibleEffectView::slotCreateGroup()
 {
     Q_EMIT createGroup(m_model);
@@ -337,9 +413,19 @@ void CollapsibleEffectView::slotUnGroup()
 
 bool CollapsibleEffectView::eventFilter(QObject *o, QEvent *e)
 {
+    if (o == collapseButton) {
+        if (e->type() == QEvent::MouseButtonPress) {
+            QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(e);
+            if (mouseEvent->modifiers() == Qt::ShiftModifier) {
+                // do what you need
+                bool doCollapse = m_collapse->isActive();
+                Q_EMIT collapseAllEffects(doCollapse);
+                return true;
+            }
+        }
+        return QWidget::eventFilter(o, e);
+    }
     if (e->type() == QEvent::Enter) {
-        frame->setProperty("mouseover", true);
-        frame->setStyleSheet(frame->styleSheet());
         return QWidget::eventFilter(o, e);
     }
     if (e->type() == QEvent::Wheel) {
@@ -406,22 +492,45 @@ QDomElement CollapsibleEffectView::effectForSave() const
 
 bool CollapsibleEffectView::isActive() const
 {
-    return decoframe->property("active").toBool();
+    return m_isActive;
 }
 
 bool CollapsibleEffectView::isEnabled() const
 {
-    return m_enabledButton->isActive();
+    return m_enabledButton == nullptr || m_enabledButton->isActive();
+}
+
+void CollapsibleEffectView::slotSetTargetEffect(bool active)
+{
+    QPalette pal = border_frame->palette();
+    if (active) {
+        pal.setColor(QPalette::Active, QPalette::Text, pal.highlight().color());
+    } else {
+        pal.setColor(QPalette::Active, QPalette::Text, pal.shadow().color());
+    }
+    border_frame->setPalette(pal);
 }
 
 void CollapsibleEffectView::slotActivateEffect(bool active)
 {
-    decoframe->setProperty("active", active);
-    decoframe->setStyleSheet(decoframe->styleSheet());
+    m_isActive = active;
+    QPalette pal = palette();
     if (active) {
+        pal.setColor(QPalette::Active, QPalette::Base, m_activeColor);
+        decoframe->setPalette(pal);
+        pal.setColor(QPalette::Active, QPalette::Base, m_activeColorTitle);
+        frame->setPalette(pal);
         pCore->getMonitor(m_model->monitorId)->slotShowEffectScene(needsMonitorEffectScene());
+        if (m_view->keyframesAllowed() && m_view->hasMultipleKeyframes()) {
+            active = pCore->itemContainsPos(m_model->getOwnerId(), pCore->getMonitor(m_model->monitorId)->position());
+        }
+    } else {
+        pal.setColor(QPalette::Active, QPalette::Base, m_bgColor);
+        decoframe->setPalette(pal);
+        pal.setColor(QPalette::Active, QPalette::Base, m_bgColorTitle);
+        frame->setPalette(pal);
     }
-    Q_EMIT m_view->initKeyframeView(active);
+    Q_EMIT m_view->initKeyframeView(active, active);
     if (m_inOutButton->isChecked()) {
         Q_EMIT showEffectZone(m_model->getOwnerId(), m_model->getInOut(), true);
     } else {
@@ -441,16 +550,28 @@ void CollapsibleEffectView::wheelEvent(QWheelEvent *e)
 void CollapsibleEffectView::leaveEvent(QEvent *event)
 {
     QWidget::leaveEvent(event);
+    if (!m_isActive) {
+        qDebug() << "::::::::::::::::::::\nLeave EFFECT\n:::::::::::::::::::\n";
+        QPalette pal = palette();
+        pal.setColor(QPalette::Active, QPalette::Base, m_bgColor);
+        decoframe->setPalette(pal);
+        pal.setColor(QPalette::Active, QPalette::Base, m_bgColorTitle);
+        frame->setPalette(pal);
+    }
     pCore->setWidgetKeyBinding(QString());
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void CollapsibleEffectView::enterEvent(QEvent *event)
-#else
 void CollapsibleEffectView::enterEvent(QEnterEvent *event)
-#endif
 {
     QWidget::enterEvent(event);
+    if (!m_isActive) {
+        qDebug() << "::::::::::::::::::::\nENBTER EFFECT\n:::::::::::::::::::\n";
+        QPalette pal = palette();
+        pal.setColor(QPalette::Active, QPalette::Base, m_hoverColorTitle);
+        frame->setPalette(pal);
+        pal.setColor(QPalette::Active, QPalette::Base, m_hoverColor);
+        decoframe->setPalette(pal);
+    }
     pCore->setWidgetKeyBinding(
         i18nc("@info:status",
               "<b>Drag</b> effect to another timeline clip, track or project clip to copy it. <b>Alt Drag</b> to copy it to a single item in a group."));
@@ -472,21 +593,25 @@ void CollapsibleEffectView::slotDisable(bool disable)
     QString effectName = EffectsRepository::get()->getName(effectId);
     Fun undo = []() { return true; };
     Fun redo = []() { return true; };
-    std::static_pointer_cast<AbstractEffectItem>(m_model)->markEnabled(!disable, undo, redo);
+    std::static_pointer_cast<AbstractEffectItem>(m_model)->markEnabled(!disable, undo, redo, false);
     if (KdenliveSettings::applyEffectParamsToGroup()) {
         pCore->applyEffectDisableToGroup(m_model->getOwnerId(), effectId, disable, undo, redo);
     }
     redo();
     pCore->pushUndo(undo, redo, disable ? i18n("Disable %1", effectName) : i18n("Enable %1", effectName));
     pCore->getMonitor(m_model->monitorId)->slotShowEffectScene(needsMonitorEffectScene());
-    Q_EMIT m_view->initKeyframeView(!disable);
+    if (!disable) {
+        disable = !pCore->itemContainsPos(m_model->getOwnerId(), pCore->getMonitor(m_model->monitorId)->position());
+    }
+    Q_EMIT m_view->initKeyframeView(!disable, disable);
     Q_EMIT activateEffect(m_model->row());
 }
 
 void CollapsibleEffectView::updateScene()
 {
     pCore->getMonitor(m_model->monitorId)->slotShowEffectScene(needsMonitorEffectScene());
-    Q_EMIT m_view->initKeyframeView(m_model->isEnabled());
+    bool contains = pCore->itemContainsPos(m_model->getOwnerId(), pCore->getMonitor(m_model->monitorId)->position());
+    Q_EMIT m_view->initKeyframeView(m_model->isAssetEnabled(), !contains);
 }
 
 void CollapsibleEffectView::slotDeleteEffect()
@@ -504,7 +629,7 @@ void CollapsibleEffectView::slotEffectDown()
     Q_EMIT moveEffect(m_model->row() + 2, m_model);
 }
 
-void CollapsibleEffectView::slotSaveEffect()
+void CollapsibleEffectView::slotSaveEffect(const QString title, const QString description)
 {
     QDialog dialog(this);
     QFormLayout form(&dialog);
@@ -516,26 +641,31 @@ void CollapsibleEffectView::slotSaveEffect()
     form.addRow(i18n("Name:"), effectName);
     form.addRow(i18n("Comments:"), descriptionBox);
 
+    effectName->setText(title);
+    descriptionBox->setText(description);
+
     QDialogButtonBox buttonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, Qt::Horizontal, &dialog);
     form.addRow(&buttonBox);
+    effectName->setFocus();
 
     QObject::connect(&buttonBox, &QDialogButtonBox::accepted, &dialog, &QDialog::accept);
     QObject::connect(&buttonBox, &QDialogButtonBox::rejected, &dialog, &QDialog::reject);
 
     if (dialog.exec() == QDialog::Accepted) {
-        QString name = effectName->text();
-        QString enteredDescription = descriptionBox->toPlainText();
-        if (name.trimmed().isEmpty()) {
+        QString name = effectName->text().simplified();
+        if (name.isEmpty()) {
             KMessageBox::error(this, i18n("No name provided, effect not saved."));
             return;
         }
+        const QString fileName = QStringUtils::getCleanFileName(name);
+        QString enteredDescription = descriptionBox->toPlainText();
         QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/effects/"));
         if (!dir.exists()) {
             dir.mkpath(QStringLiteral("."));
         }
 
-        if (dir.exists(name + QStringLiteral(".xml")))
-            if (KMessageBox::questionTwoActions(this, i18n("File %1 already exists.\nDo you want to overwrite it?", name + QStringLiteral(".xml")), {},
+        if (dir.exists(fileName + QStringLiteral(".xml")))
+            if (KMessageBox::questionTwoActions(this, i18n("File %1 already exists.\nDo you want to overwrite it?", fileName + QStringLiteral(".xml")), {},
                                                 KStandardGuiItem::overwrite(), KStandardGuiItem::cancel()) == KMessageBox::SecondaryAction) {
                 return;
             }
@@ -547,7 +677,7 @@ void CollapsibleEffectView::slotSaveEffect()
         // Adjust param values
         QVector<QPair<QString, QVariant>> currentValues = m_model->getAllParameters();
         QMap<QString, QString> values;
-        for (const auto &param : qAsConst(currentValues)) {
+        for (const auto &param : std::as_const(currentValues)) {
             values.insert(param.first, param.second.toString());
         }
         QDomNodeList params = effect.elementsByTagName("parameter");
@@ -584,6 +714,9 @@ void CollapsibleEffectView::slotSaveEffect()
             namedId.prepend(QStringLiteral("fadeout_"));
         }
         effect.setAttribute(QStringLiteral("id"), namedId);
+        if (m_model->isBuiltIn()) {
+            effect.setAttribute(QStringLiteral("buildtin"), QStringLiteral("1"));
+        }
         effect.setAttribute(QStringLiteral("type"), m_model->isAudio() ? QStringLiteral("customAudio") : QStringLiteral("customVideo"));
 
         QDomElement effectname = effect.firstChildElement(QStringLiteral("name"));
@@ -595,12 +728,12 @@ void CollapsibleEffectView::slotSaveEffect()
         QDomElement effectprops = effect.firstChildElement(QStringLiteral("properties"));
         effectprops.setAttribute(QStringLiteral("id"), name);
         effectprops.setAttribute(QStringLiteral("type"), QStringLiteral("custom"));
-        QFile file(dir.absoluteFilePath(name + QStringLiteral(".xml")));
+        QFile file(dir.absoluteFilePath(fileName + QStringLiteral(".xml")));
 
         if (!enteredDescription.trimmed().isEmpty()) {
             QDomElement root = doc.documentElement();
             QDomElement nodelist = root.firstChildElement("description");
-            QDomElement newNodeTag = doc.createElement(QString("description"));
+            QDomElement newNodeTag = doc.createElement(QStringLiteral("description"));
             QDomText text = doc.createTextNode(enteredDescription);
             newNodeTag.appendChild(text);
             root.replaceChild(newNodeTag, nodelist);
@@ -608,41 +741,17 @@ void CollapsibleEffectView::slotSaveEffect()
 
         if (file.open(QFile::WriteOnly | QFile::Truncate)) {
             QTextStream out(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            out.setCodec("UTF-8");
-#endif
             out << doc.toString();
+            file.close();
         } else {
             KMessageBox::error(this, i18n("Cannot write to file %1", file.fileName()));
+            slotSaveEffect(name, enteredDescription);
+            return;
         }
-        file.close();
-        Q_EMIT reloadEffect(dir.absoluteFilePath(name + QStringLiteral(".xml")));
+        Q_EMIT reloadEffect(dir.absoluteFilePath(fileName + QStringLiteral(".xml")));
     }
 }
 
-QDomDocument CollapsibleEffectView::toXml() const
-{
-    QDomDocument doc;
-    // Get base effect xml
-    QString effectId = m_model->getAssetId();
-    // Adjust param values
-    QVector<QPair<QString, QVariant>> currentValues = m_model->getAllParameters();
-
-    QDomElement effect = doc.createElement(QStringLiteral("effect"));
-    doc.appendChild(effect);
-    effect.setAttribute(QStringLiteral("id"), effectId);
-    for (const auto &param : qAsConst(currentValues)) {
-        QDomElement xmlParam = doc.createElement(QStringLiteral("property"));
-        effect.appendChild(xmlParam);
-        xmlParam.setAttribute(QStringLiteral("name"), param.first);
-        QString value;
-        value = param.second.toString();
-        QDomText val = doc.createTextNode(value);
-        xmlParam.appendChild(val);
-    }
-    return doc;
-}
-
 void CollapsibleEffectView::slotResetEffect()
 {
     m_view->resetValues();
@@ -654,7 +763,8 @@ void CollapsibleEffectView::updateHeight()
         return;
     }
     widgetFrame->setFixedHeight(m_collapse->isActive() ? 0 : m_view->height());
-    setFixedHeight(widgetFrame->height() + frame->minimumHeight() + zoneFrame->minimumHeight() + 2 * (contentsMargins().top() + decoframe->lineWidth()));
+    setFixedHeight(widgetFrame->height() + border_frame->minimumHeight() + frame->minimumHeight() + zoneFrame->minimumHeight() +
+                   2 * (contentsMargins().top() + decoframe->lineWidth()));
     Q_EMIT switchHeight(m_model, height());
 }
 
@@ -667,10 +777,13 @@ void CollapsibleEffectView::switchCollapsed(int row)
 
 void CollapsibleEffectView::slotSwitch(bool collapse)
 {
-    widgetFrame->setFixedHeight(collapse ? 0 : m_view->height());
+    widgetFrame->setFixedHeight(collapse ? 0 : m_view->sizeHint().height());
     zoneFrame->setFixedHeight(collapse || !m_inOutButton->isChecked() ? 0 : frame->height());
-    setFixedHeight(widgetFrame->height() + frame->minimumHeight() + zoneFrame->height() + 2 * (contentsMargins().top() + decoframe->lineWidth()));
+    setFixedHeight(widgetFrame->height() + border_frame->minimumHeight() + frame->minimumHeight() + zoneFrame->height() +
+                   2 * (contentsMargins().top() + decoframe->lineWidth()));
     m_model->setCollapsed(collapse);
+    keyframesButton->setVisible(!collapse);
+    inOutButton->setVisible(!collapse);
     Q_EMIT switchHeight(m_model, height());
 }
 
@@ -722,17 +835,6 @@ int CollapsibleEffectView::effectIndex() const
     return m_effect.attribute(QStringLiteral("kdenlive_ix")).toInt();
 }
 
-void CollapsibleEffectView::updateWidget(const ItemInfo &info, const QDomElement &effect)
-{
-    Q_UNUSED(info)
-    // cleanup
-    /*
-    delete m_paramWidget;
-    m_paramWidget = nullptr;
-    */
-    m_effect = effect;
-}
-
 void CollapsibleEffectView::updateFrameInfo()
 {
     /*
@@ -799,77 +901,18 @@ void CollapsibleEffectView::dragEnterEvent(QDragEnterEvent *event)
     */
 }
 
+void CollapsibleEffectView::resizeEvent(QResizeEvent *event)
+{
+    QWidget::resizeEvent(event);
+    m_view->adjustSize();
+    m_view->updateGeometry();
+}
+
 void CollapsibleEffectView::dragLeaveEvent(QDragLeaveEvent * /*event*/)
 {
-    frame->setProperty("target", false);
-    frame->setStyleSheet(frame->styleSheet());
-}
-
-void CollapsibleEffectView::importKeyframes(const QString &kf)
-{
-    QMap<QString, QString> keyframes;
-    if (kf.contains(QLatin1Char('\n'))) {
-        const QStringList params = kf.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
-        for (const QString &param : params) {
-            keyframes.insert(param.section(QLatin1Char('='), 0, 0), param.section(QLatin1Char('='), 1));
-        }
-    } else {
-        keyframes.insert(kf.section(QLatin1Char('='), 0, 0), kf.section(QLatin1Char('='), 1));
-    }
-    Q_EMIT importClipKeyframes(AVWidget, m_itemInfo, m_effect.cloneNode().toElement(), keyframes);
-}
-
-void CollapsibleEffectView::dropEvent(QDropEvent *event)
-{
-    if (event->mimeData()->hasFormat(QStringLiteral("kdenlive/geometry"))) {
-        if (event->source()->objectName() == QStringLiteral("ParameterContainer")) {
-            return;
-        }
-        QString itemData = event->mimeData()->data(QStringLiteral("kdenlive/geometry"));
-        importKeyframes(itemData);
-        return;
-    }
-    frame->setProperty("target", false);
-    frame->setStyleSheet(frame->styleSheet());
-    const QString effects = QString::fromUtf8(event->mimeData()->data(QStringLiteral("kdenlive/effectslist")));
-    // event->acceptProposedAction();
-    QDomDocument doc;
-    doc.setContent(effects, true);
-    QDomElement e = doc.documentElement();
-    int ix = e.attribute(QStringLiteral("kdenlive_ix")).toInt();
-    int currentEffectIx = effectIndex();
-    if (ix == currentEffectIx || e.attribute(QStringLiteral("id")) == QLatin1String("speed")) {
-        // effect dropped on itself, or unmovable speed dropped, reject
-        event->ignore();
-        return;
-    }
-    if (ix == 0 || e.tagName() == QLatin1String("effectgroup")) {
-        if (e.tagName() == QLatin1String("effectgroup")) {
-            // moving a group
-            QDomNodeList subeffects = e.elementsByTagName(QStringLiteral("effect"));
-            if (subeffects.isEmpty()) {
-                event->ignore();
-                return;
-            }
-            event->setDropAction(Qt::MoveAction);
-            event->accept();
-            Q_EMIT addEffect(e);
-            return;
-        }
-        // effect dropped from effects list, add it
-        e.setAttribute(QStringLiteral("kdenlive_ix"), ix);
-        /*if (m_info.groupIndex > -1) {
-            // Dropped on a group
-            e.setAttribute(QStringLiteral("kdenlive_info"), m_info.toString());
-        }*/
-        event->setDropAction(Qt::CopyAction);
-        event->accept();
-        Q_EMIT addEffect(e);
-        return;
-    }
-    // Q_EMIT moveEffect(QList<int>() << ix, currentEffectIx, m_info.groupIndex, m_info.groupName);
-    event->setDropAction(Qt::MoveAction);
-    event->accept();
+    QPalette pal = border_frame->palette();
+    pal.setColor(QPalette::Active, QPalette::Text, pal.shadow().color());
+    border_frame->setPalette(pal);
 }
 
 void CollapsibleEffectView::adjustButtons(int ix, int max)
@@ -880,7 +923,7 @@ void CollapsibleEffectView::adjustButtons(int ix, int max)
 
 MonitorSceneType CollapsibleEffectView::needsMonitorEffectScene() const
 {
-    if (!m_model->isEnabled() || !m_view) {
+    if (!m_model->isAssetEnabled() || !m_view) {
         return MonitorSceneDefault;
     }
     return m_view->needsMonitorEffectScene();
@@ -900,16 +943,11 @@ bool CollapsibleEffectView::isMovable() const
     return m_isMovable;
 }
 
-void CollapsibleEffectView::prepareImportClipKeyframes()
-{
-    Q_EMIT importClipKeyframes(AVWidget, m_itemInfo, m_effect.cloneNode().toElement(), QMap<QString, QString>());
-}
-
 void CollapsibleEffectView::enableView(bool enabled)
 {
-    m_enabledButton->setActive(enabled);
-    title->setEnabled(!enabled);
-    if (enabled) {
+    m_enabledButton->setActive(!enabled);
+    title->setEnabled(enabled);
+    if (!enabled) {
         if (KdenliveSettings::disable_effect_parameters()) {
             widgetFrame->setEnabled(false);
         }
@@ -928,31 +966,41 @@ void CollapsibleEffectView::blockWheelEvent(bool block)
 {
     m_blockWheel = block;
     Qt::FocusPolicy policy = block ? Qt::StrongFocus : Qt::WheelFocus;
-    for (QSpinBox *sp : findChildren<QSpinBox *>()) {
+    const QList<QSpinBox *> spins = findChildren<QSpinBox *>();
+    for (QSpinBox *sp : spins) {
         sp->installEventFilter(this);
         sp->setFocusPolicy(policy);
     }
-    for (QComboBox *cb : findChildren<QComboBox *>()) {
+    const QList<QComboBox *> combos = findChildren<QComboBox *>();
+    for (QComboBox *cb : combos) {
         cb->installEventFilter(this);
         cb->setFocusPolicy(policy);
     }
-    for (QProgressBar *cb : findChildren<QProgressBar *>()) {
+    const QList<QProgressBar *> progs = findChildren<QProgressBar *>();
+    for (QProgressBar *cb : progs) {
         cb->installEventFilter(this);
         cb->setFocusPolicy(policy);
     }
-    for (WheelContainer *cb : findChildren<WheelContainer *>()) {
+    const QList<WheelContainer *> wheels = findChildren<WheelContainer *>();
+    for (WheelContainer *cb : wheels) {
         cb->installEventFilter(this);
         cb->setFocusPolicy(policy);
     }
-    for (QDoubleSpinBox *cb : findChildren<QDoubleSpinBox *>()) {
+    const QList<QDoubleSpinBox *> dspins = findChildren<QDoubleSpinBox *>();
+    for (QDoubleSpinBox *cb : dspins) {
         cb->installEventFilter(this);
         cb->setFocusPolicy(policy);
     }
-    for (KeyframeWidget *cb : findChildren<KeyframeWidget *>()) {
-        for (KeyframeView *cb2 : cb->findChildren<KeyframeView *>()) {
-            cb2->installEventFilter(this);
-            cb2->setFocusPolicy(policy);
-        }
+    const QList<DragValue *> drags = m_view->findChildren<DragValue *>();
+    for (DragValue *cb : drags) {
+        cb->blockWheel(m_blockWheel);
+        cb->installEventFilter(this);
+        cb->setFocusPolicy(policy);
+    }
+    const QList<KeyframeView *> kfs = findChildren<KeyframeView *>();
+    for (KeyframeView *cb : kfs) {
+        cb->installEventFilter(this);
+        cb->setFocusPolicy(policy);
     }
 }
 
@@ -966,9 +1014,15 @@ void CollapsibleEffectView::switchInOut(bool checked)
     if (inOut.first == inOut.second || !checked) {
         ObjectId owner = m_model->getOwnerId();
         switch (owner.type) {
-        case KdenliveObjectType::TimelineClip: {
-            int in = pCore->getItemIn(owner);
-            inOut = {in, in + pCore->getItemDuration(owner)};
+        case KdenliveObjectType::BinClip: {
+            int lastOut = m_model->filter().get_int("_kdenlive_zone_out");
+            if (lastOut > 0) {
+                int in = m_model->filter().get_int("_kdenlive_zone_in");
+                inOut = {in, lastOut};
+            } else {
+                int in = pCore->getItemIn(owner);
+                inOut = {in, in + pCore->getItemDuration(owner)};
+            }
             break;
         }
         case KdenliveObjectType::TimelineTrack:
@@ -976,8 +1030,39 @@ void CollapsibleEffectView::switchInOut(bool checked)
             if (!checked) {
                 inOut = {0, 0};
             } else {
-                int in = pCore->getMonitorPosition();
-                inOut = {in, in + pCore->getDurationFromString(KdenliveSettings::transition_duration())};
+                int lastOut = m_model->filter().get_int("_kdenlive_zone_out");
+                if (lastOut > 0) {
+                    int in = m_model->filter().get_int("_kdenlive_zone_in");
+                    inOut = {in, lastOut};
+                } else {
+                    int in = pCore->getMonitorPosition();
+                    inOut = {in, in + pCore->getDurationFromString(KdenliveSettings::transition_duration())};
+                }
+            }
+            break;
+        }
+        case KdenliveObjectType::TimelineClip: {
+            if (!checked) {
+                inOut = {0, 0};
+            } else {
+                int lastOut = m_model->filter().get_int("_kdenlive_zone_out");
+                if (lastOut > 0) {
+                    int in = m_model->filter().get_int("_kdenlive_zone_in");
+                    inOut = {in, lastOut};
+                } else {
+                    int clipIn = pCore->getItemPosition(owner);
+                    int clipOut = clipIn + pCore->getItemDuration(owner);
+                    int in = pCore->getMonitorPosition();
+                    if (in > clipIn && in < clipOut) {
+                        // Cursor is inside the clip, set zone from here
+                        in = in - clipIn;
+                    } else {
+                        in = 0;
+                    }
+                    int out = in + pCore->getDurationFromString(KdenliveSettings::transition_duration());
+                    out = qBound(in, out, clipOut);
+                    inOut = {in, out};
+                }
             }
             break;
         }
@@ -1003,6 +1088,15 @@ void CollapsibleEffectView::updateInOut(QPair<int, int> inOut, bool withUndo)
     QString effectId = m_model->getAssetId();
     QString effectName = EffectsRepository::get()->getName(effectId);
     if (inOut.first > -1) {
+        ObjectId owner = m_model->getOwnerId();
+        if (owner.type == KdenliveObjectType::TimelineClip) {
+            int in = pCore->getItemPosition(owner);
+            int duration = pCore->getItemDuration(owner);
+            inOut.first -= in;
+            inOut.second -= in;
+            inOut.first = qBound(0, inOut.first, duration);
+            inOut.second = qBound(inOut.first, inOut.second, duration);
+        }
         m_model->setInOut(effectName, inOut, true, withUndo);
         m_inPos->setValue(inOut.first);
         m_outPos->setValue(inOut.second);
@@ -1039,7 +1133,7 @@ void CollapsibleEffectView::slotHideKeyframes(bool hide)
 
 void CollapsibleEffectView::sendStandardCommand(int command)
 {
-    m_view->sendStandardCommand(command);
+    Q_EMIT m_view->sendStandardCommand(command);
 }
 
 int CollapsibleEffectView::getEffectRow() const
@@ -1056,3 +1150,18 @@ const QString CollapsibleEffectView::getAssetId() const
 {
     return m_model->getAssetId();
 }
+
+void CollapsibleEffectView::enableAndExpand()
+{
+    if (m_enabledButton->isActive()) {
+        m_enabledButton->setActive(false);
+        slotDisable(false);
+    }
+    m_collapse->setActive(false);
+    Q_EMIT activateEffect(m_model->row());
+}
+
+void CollapsibleEffectView::collapseEffect(bool collapse)
+{
+    m_collapse->setActive(!collapse);
+}
